@@ -1,8 +1,92 @@
-function postPhoto(context, access_token) {
+// global variable to store canvas data
+var canvasDataSnapshot = "";
 
+//draw photo to canvas
+function drawPhoto(context,image_src, callback) {
+  var img = new Image();
+  img.src = image_src;
+  img.onload = function() {
+    context.drawImage(img,0,91,img.width,img.height);
+    if (typeof callback !== "undefined") {
+      callback(context);
+    }
+  };
+}
+
+function saveImage() {
+  var canvas = document.getElementById("canvas"),
+  context = canvas.getContext("2d");
+  var img = new Image();
+  img.src = $('#preview img').data('cropbox').getDataURL("image/png");
+  img.onload = function() {
+    context.drawImage(img,0,91,img.width,img.height);
+    canvasDataSnapshot = context.canvas.toDataURL("image/png");
+   }
+}
+
+function drawFrame(context, callback) {
+  options = {
+    name : $('#name').val(),
+    frame_url: frame_url
+  };
+
+    //lay out the frame
+    if (options.frame_url !== "undefined") {
+      var frame = new Image();
+      frame.src = options.frame_url;
+      frame.onload = function() {
+        var canvas = context.canvas;
+        context.drawImage(frame,0,0,canvas.clientWidth,canvas.clientHeight);
+        //lay out the name
+        if (options.name !== "undefined") {
+          context.fillStyle = "#FFF";
+          context.font = "bold 32px House Slant";
+          context.textAlign = "start";
+          context.fillText(options.name, 140, 53);
+        }
+
+        if (typeof callback !== "undefined") {
+          callback(context);
+        }
+      };
+    }
+
+}
+
+var postRawPhoto = function(form, dropbox) {
+        $.ajax({
+            type: 'POST',
+            url:"upload_raw_photo",
+            contentType: false,
+            processData: false,
+            data: form,
+        error: function(data) {
+            alert('Please select a photo to upload before submitting.')
+        },
+        success: function(data) {
+            console.log(data);
+            var data = $.parseJSON(data);
+            //clears canvas
+            var canvas = document.getElementById("canvas");
+            var context = canvas.getContext("2d");
+            context.setTransform(1, 0, 0, 1, 0, 0);
+            context.clearRect(0,0,canvas.width,canvas.height);
+            current_image = new Image()
+            current_image.src = 'data:image/png;base64, ' + data['resized_file']
+            dropbox.appendChild(current_image);
+            initCropper();
+            context = document.getElementById("canvas").getContext("2d");
+            drawFrame(context);
+        }
+    });
+}
+
+
+
+function postPhoto(context, access_token) {
   $('input').removeClass('error');
   $('label').removeClass('error');
-  var base64img = context.canvas.toDataURL();
+  var base64img = context.canvas.toDataURL("image/png");
   $.ajax({
     type: 'POST',
     url: 'submit',
@@ -27,41 +111,6 @@ function postPhoto(context, access_token) {
   });
 }
 
-function drawFrame(context, callback) {
-  options = {
-    name : $('#name').val(),
-    frame_url: frame_url
-  };
-
-    //lay out the frame
-
-    if (options.frame_url !== "undefined") {
-      var frame = new Image();
-      frame.src = options.frame_url;
-      frame.onload = function() {
-        var canvas = context.canvas;
-        context.drawImage(frame,0,0,canvas.clientWidth,canvas.clientHeight);
-        //lay out the name
-        if (options.name !== "undefined") {
-          context.fillStyle = "#FFF";
-          context.font = "bold 32px House Slant";
-          context.textAlign = "start";
-          context.fillText(options.name, 140, 53);
-        }
-
-        if (typeof callback !== "undefined") {
-          callback(context);
-        }
-      };
-    }
-
-  }
-
-  function switchStep(current, next) {
-    $('[data-step="' + current + '"]').hide();
-    $('[data-step="' + next + '"]').show();
-  }
-
 //redraw when we add text and such
 function redraw() {
   var canvas = document.getElementById("canvas"),
@@ -69,28 +118,28 @@ function redraw() {
   drawPhoto(context,$('#preview img').attr('src'), drawFrame);
 }
 
+// update the global canvasDataSnapshot variable
+function updateCanvasDataSnapshot() {
+    var canvas = document.getElementById("canvas");
+    var imageData = canvas.toDataURL("image/png");
+    canvasDataSnapshot = imageData;
+    console.log("canvas snapshot updated");
+}
+
+function switchStep(current, next) {
+  $('[data-step="' + current + '"]').hide();
+  $('[data-step="' + next + '"]').show();
+}
+
 function initCropper() {
   $('#preview img').cropbox({
     "width":390,
     "height":263
   });
-
 }
 
-//draw photo to canvas
-function drawPhoto(context,image_src, callback) {
-  var img = new Image();
-  img.src = image_src;
-  img.onload = function() {
-    context.drawImage(img,0,91,img.width,img.height);
-    if (typeof callback !== "undefined") {
-      callback(context);
-    }
-  };
-}
-
-function downloadCanvas(link, canvasId, filename) {
-  link.href = document.getElementById(canvasId).toDataURL();
+function downloadCanvas(link, imgData, filename) {
+  link.href = imgData;
   link.download = filename;
 }
 
@@ -106,6 +155,25 @@ function imageUpload(dropbox) {
   var current_image = null;
   var ias = null;
   var file = $("#fileInput").get(0).files[0];
+  
+      // this isn't really doing anything yet, just loading in 
+      // the orientation data to potentially do something with,
+      // using the loadImage plugin
+      loadImage.parseMetaData(
+          file,
+          function (data) {
+              if (!data.imageHead) {
+                console.log("no data in my image head");
+                  return;
+              }
+
+              // var orientation = data.exif.getAll();
+              var orientation = data.exif.get('Orientation');
+              // console.log("Photo orientation code:");
+              // console.log(orientation);
+          }
+      );
+
       //var file = document.getElementById('fileInput').files[0];
       var imageType = /image.*/;
 
@@ -113,18 +181,12 @@ function imageUpload(dropbox) {
         var reader = new FileReader();
 
         reader.onload = function(e) {
+          var file = $("#fileInput")[0].files[0];
+          var rawPhotoForm = new FormData($('#rawPhoto')[0]);
+          rawPhotoForm.append('photo', file);
+          console.log(rawPhotoForm);
           switchStep(1,2);
-
-          // Create a new image with image crop functionality
-          current_image = new Image();
-          current_image.src = reader.result;
-          current_image.id = "photo";
-
-          // Add image to dropbox element
-          dropbox.appendChild(current_image);
-          initCropper();
-          context = document.getElementById("canvas").getContext("2d");
-          drawFrame(context);
+          postRawPhoto(rawPhotoForm, dropbox);
         }
         reader.readAsDataURL(file);
 
@@ -134,12 +196,51 @@ function imageUpload(dropbox) {
     }
 
     $("#name").change(function() {
+
       var canvas = document.getElementById("canvas"),
       context = canvas.getContext("2d");
-      drawFrame(context)
+      drawFrame(context);
+      saveImage();
+
     });
 
-    
+    function charCountDown(inputEl, counterEl) {
+          if(!inputEl || !counterEl){return false}; // catches errors
+          var limit = inputEl.maxLength;
+          var counter = counterEl;
+          var remaining = limit - inputEl.value.length;
+          counter.innerHTML = remaining+ " of " + limit + " remaining";
+    }
+
+    $("#examplePhoto").click(function() {
+      // Hack - hardcode aspect ratio
+      $('#fileInput').click();
+    });
+
+    $('#fileInput').change(function(e) {      
+      imageUpload($('#preview').get(0));
+    });
+
+    // character count
+    $("#name").keypress( function() {
+      var inputEl = document.getElementById("name");
+      var counterEl = document.getElementById("charcount");
+      charCountDown(inputEl, counterEl);
+    });
+
+    $('#saveme').click( function(e){
+      e.preventDefault();
+      saveImage();
+    });
+
+    // new download function binding directly to element
+    document.getElementById("download").addEventListener('click', function(e) {
+      link = this;
+      link.href = canvasDataSnapshot;
+      link.download = 'walmart-test.png';
+
+    }, false);
+
 
     $("#share-to-facebook").on('click', function(e) {
       e.preventDefault();
@@ -150,7 +251,7 @@ function imageUpload(dropbox) {
          // TODO: Maybe make a try/catch instead and provide a real error...
          if (response.authResponse) {
             var access_token =   FB.getAuthResponse()['accessToken'];
-            drawPhoto(context,$('#preview img').data('cropbox').getDataURL(), postPhoto(context, access_token));
+            drawPhoto(context,$('#preview img').data('cropbox').getDataURL("image/png"), postPhoto(context, access_token));
          } else {
             console.log("User cancelled login or did not fully authorize");
          }
@@ -158,22 +259,6 @@ function imageUpload(dropbox) {
 
     });
 
-    $("#examplePhoto").click(function() {
-      // Hack - hardcode aspect ratio
-      $('#fileInput').click();
-    });
-
-    $('#fileInput').change(function(click) {
-      imageUpload($('#preview').get(0));
-      // Reset input value
-      $(this).val("");
-    });
-
-    $("#download").on('click', function(e) {
-      e.preventDefault();
-      downloadCanvas(this, 'canvas', 'walmart-coc.png');
-    })
-
     $(document).ready(function() {
     // Todo: Add Facebook app ID as a package setting.
       $.ajaxSetup({ cache: true });
@@ -183,19 +268,4 @@ function imageUpload(dropbox) {
         });     
       });
 
-  });
-
-
-// viewport = document.querySelector("meta[name=viewport]");
-// viewport.setAttribute('content', 'width=440, initial-scale=.6, maximum-scale=1, user-scalable=0');
-
-
-// var hammertime = new Hammer(document.getElementById("photo"));
-
-// hammertime.get('pan').set({ direction: Hammer.DIRECTION_ALL });
-
-// hammertime.on('pan', function(ev) {
-//     console.log(ev);
-// });
-
-
+  });
\ No newline at end of file
